//layout toc title(subsubsection) link(subsubsection) secbold 
//layout toc subsubsubsecitalic 
//file homogamy.dta

//toctitle Making interactive presentations in Stata

/*toctxt

{center:Maarten L. Buis}
{center:University of Konstanz}

toctxt*/

//section Example presentation: stdtable, a package to standardize tables
//subsection Standardized table

//slide ------------------------------------------------------------------------
//title The influence of marginal distributions

/*txt
{pstd}
Consider the example below

{pstd}
It shows the race of the husband and the race of the wife for couples living in 
the USA that got married between 2010 and 2016

{pstd}
The races are very unequaly distributed in the USA

{pstd}
We can control for one marginal distribution by computing row or collumn 
percentages.
txt*/

//ex
use homogamy, clear
tab racem racef [fw=freq] if marcoh == 2010, row nofreq
//endex

/*txt
{pstd}
We see racial homogamy: people tend to marry someone of the same race

{pstd}
The exception appears to be the native Americans: only 43% of native American men
married native American women and 43% married a non-hispanic white women.

{pstd}
However, there are many more white women around than native american women (67% 
versus 0.8%).

{pstd}
If native Americans were mixing around randomly, then we would expect much more
native American men marrying white women.

{pstd}
Apperently native American men still prefer native American women but because 
there are so many more white women around he will still have a good chance of 
eventually marrying a white women. 

{pstd}
There is something mechanical about this, and it is common (in sociology) to want
to look at the pattern in the table nett of this influence of the marginal 
distributions.

{pstd}
We could do this by looking at /*digr*/ , but here I want to show an alternative.
txt*/

//endslide ---------------------------------------------------------------------

//digr -------------------------------------------------------------------------
//title Odds ratios
//label odds ratios

/*txt
{pstd}
The odds is the number of "successes" per "failure"

{pstd}
The odds ratio is a ratio of odds, and this measure of association is indpendent
of the marginal distributions
txt*/

//ex
tab racem racef [fw=freq] if marcoh == 2010
di 59227 / 59096
di 61383 / 11842951
di (59227 / 59096)/(61383 / 11842951)
//endex

/*txt
{pstd}
In this case we find about 1 native american man marrying a native american women
for every native american man marrying a white women 

{pmore}
odds of marrying a native american women compared to a white women is "only" 1 
for native american man

{pstd}
We find about 0.005 white man marrying a native american women for every white 
man marrying a white women. 

{pmore}
odds of marrying a native american women compared to a white women is 0.05 for 
white man.

{pstd}
The odds of marrying a native american women compared to a white women is 193 
times larger for native American man than for white man. 

txt*/
//enddigr  ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Standardizing tables

/*txt
{pstd}
When we do a chi squared test for cross-tabulations we compare observed cell counts 
with predicted cell counts 

{pstd}
For these predicted cell counts we assume that the margins remain as observed, 
but otherwise there is no association between the variables (the odds ratios are
all 1).

{pstd}
In the table of predicted cell counts the only pattern is due to the margins.
txt*/

//ex
tab racem racef [fw=freq] if marcoh==2010, exp
//endex

/*txt
{pstd}
Can't we reverse that? Keep the association as observed but fix the margins. 

{pstd}
For example we could fix all margins at a 100.

{pstd}
That way we can look at the proportion native American men marrying native American
women when they weren't such a small group.

{pstd}
This is what the {helpb stdtable} package does.
txt*/

//ex
stdtable racem racef [fw=freq] if marcoh == 2010, cellwidth(9) 
//endex

/*txt
{pstd}
To illustrate what keeping the association as observed means we can look at the 
odds ratios in the original table and in the standardized table 

{pstd}
Below we look at the odds ratio comparing the odds of marrying a native american 
women versus a white women when one is a native american or a white man.

{pstd}
This odds ratio in the original data is the same as that odds ratio in the
standardized table
txt*/

//ex
stdtable racem racef [fw=freq] if marcoh == 2010, ///
    raw format(%10.6g) cellwidth(10)
di (59227/59096)/(61383/11842951)
di (88.3671/ 6.31711)/(5.43302/ 75.1003)
//endex

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Displaying results from stdtable

/*txt
{pstd}
We can add options to make the table look better
txt*/

//ex
stdtable racem racef [fw=freq] if marcoh == 2010, ///
         cellwidth(9) format(%5.0f)  
//endex

/*txt
{pstd}
Alternatively we can replace the data in memory with standardized counts and 
use those to create a graph
txt*/

//ex
stdtable racem racef [fw=freq],              ///
    cellwidth(9) format(%5.0f)               ///
    by(marcoh) replace
	
tabplot racem marcoh [iw=std],               ///
    by(racef, compact note("") cols(5))      ///
    xlab( 1(1)6, angle(35) labsize(vsmall) ) ///
    showval( format(%5.0f))
//endex
//graph Graph

//endslide ---------------------------------------------------------------------

//subsection Iterative Proportional Fitting

//slide ------------------------------------------------------------------------
//title Making all the row totals 100
/*txt
{pstd}
{cmd:stdtable} standardizes a table using Iterative Proportional Fitting

{pstd}
To illustrate how that works we will do a few iterations in Mata

{pstd}Notice, that I added the option {cmd:matcell(data)} to the {cmd:tab} 
command. This leaves behind the table as a Stata matrix named data, which in turn
can be read into Mata{p_end}
txt*/

//ex load the data in Mata
use homogamy, clear
tab racem racef [fw=freq] if marcoh==2010, matcell(data)
mata
data = st_matrix("data")
data
end
//endex

/*txt
{pstd}If we divide all cell entries by the rowsum, then the new rowsum will be 1.{p_end}

{pstd}Multiply the new cell entries by a 100, and the rowsum will be a 100.{p_end}
txt*/

//ex adjust the rows to sum to 100
mata
muhat = data

muhat = muhat:/rowsum(muhat):*100
muhat
rowsum(muhat)
colsum(muhat)
end
//endex
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Making all the colum totals 100

/*txt
{pstd}The row totals are as we want them, but the column totals are not. What
if we repeat this process for the columns?{p_end}
txt*/

//ex adjust the columns to sum to 100
mata
muhat = muhat:/colsum(muhat):*100
muhat
rowsum(muhat)
colsum(muhat)
end
//endex

/*txt
{pstd}Now the column totals are as we want them, but now the row totals are a
bit off.{p_end}

{pstd}However, the row totals are better than in the original table, so maybe
we need to repeat this process a couple of times?{p_end}
txt*/
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Repeat
//ex repeat adjusting rows and colums
mata
muhat = muhat:/rowsum(muhat):*100
muhat
rowsum(muhat)
colsum(muhat)

muhat = muhat:/colsum(muhat):*100
muhat
rowsum(muhat)
colsum(muhat)
end
//endex
/*txt
{pstd}Notice that each time we get a bit closer to our goal{p_end}

{pstd}
Iterative Proportional Fitting continues till convergence.
txt*/
//endslide ---------------------------------------------------------------------

//anc --------------------------------------------------------------------------
//title Can all tables be standardized?

/*txt
{pstd}Consider the following table{p_end}

        0 0 2
        1 5 2
        8 7 0
	
{pstd}In order to make the first row total 100, the top right cell {it:must} be 
100{p_end}	

{pstd}In order to make the last column total 100, the top right cell {it:cannot} 
be 100{p_end}

{pstd}This is an example of a table that cannot be standardized, and the algorithm 
will not converge.
txt*/
//endanc -----------------------------------------------------------------------

//section How to create a smcl presentation
//subsection creating the presentation
//slide ------------------------------------------------------------------------
//title Getting started

/*txt
{pstd}
I typically start with creating the examples.

{pstd}
I typically do this in a single .do file and use comments to structure my ideas

{pstd}
Here is the .do file for the example presentation

//ho_ignore {pstd}{stata "doedit example_pres01.do":example_pres01.do}{p_end}
txt*/
//codefile example_pres01.do


/*txt

{pstd}
Next step is to Indicate when a slide begins with {cmd://slide} and ends with 
{cmd://endslide}

{pstd}
With the {cmd://title} one specifies the title of the slide

{pstd}
Examples are indicated by {cmd://ex} and {cmd://endex}

{pstd}
Sections are indicated by {cmd://section} {it:section_name}

{pstd}
This is what we get:

//ho_ignore {pstd}{stata "doedit example_pres02.do":example_pres02.do}{p_end}
txt*/
//codefile example_pres02.do

/*txt
{pstd}
This is already a sourcefile we can use for {cmd:smclpres}
txt*/

//ex
smclpres using example_pres02.do , replace dir(output)
cd output
dir
cd ..
//endex
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Adding text

/*txt
{pstd}
You can add a text block by starting a line with {cmd:/*txt} and ending it with 
{cmd:txt*/}

{pstd}
The text will be formatted using SMCL, which is documented in {help smcl:help smcl}

{pstd}
The most important directives are:

{pmore}
{cmd:{c -(}pstd{c )-}} starts a standard paragraph

{pmore}
{cmd:{c -(}pmore{c )-}} starts an indented paragraph

{pmore}
{cmd:{c -(}p_end{c )-}} ends a paragraph

{pmore}
{cmd:{c -(}help} {it:cmd_name}{cmd:{c )-}} adds a link to the helpfile of {it:cmd_name}.

{pstd}
The sourcefile after including text looks like this:

//ho_ignore {pstd}{stata "doedit example_pres03.do":example_pres03.do}{p_end}
txt*/
//codefile example_pres03.do

//ex
smclpres using example_pres03.do , replace dir(output)
//endex

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Different kinds of slides

/*txt
{pstd}
The {bf:normal slides} (what we have used thus far) represent the main linear flow of
the presentation.

{pstd}
We can also add {bf:digression slides}. The arrows at the bottom of a slide will skip 
it, but you must add a link to it in a text block on the previous regular slide.

{pstd}
So during the presentation, the presenter can easily decide whether or not to 
skip the digression slide.

{pmore}
You specify the digression slide using {cmd://digr} and {cmd://enddigr}

{pmore}
You specify the where the link will appear in the previous slide using {cmd:/*digr*/}

{pmore}
You specify the label used for the link using {cmd://label}

{pstd}
Alternatively we can add a ancillary slide, which can only be accessed from the
index slide

{pstd}
This type of slide serves the purpose of an appendix.

{pmore}
You specify the {bf:ancillary slide} using {cmd://anc} and {cmd://endanc}

{pstd}
The sourcefile after including a digression and an ancillary slide looks like this:

//ho_ignore {pstd}{stata "doedit example_pres04.do":example_pres04.do}{p_end}
txt*/
//codefile example_pres04.do

//ex
smclpres using example_pres04.do , replace dir(output)
//endex


//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Changing the look of the table of contents

/*txt
{pstd}
You can specify settings for the overall layout of the presentation using the 
{cmd://layout} command. 

{pstd} 
For example, {cmd://layout toc title(subsection)} specifies that the slide titles
are added to the table of content as a subsection.

{pmore}
In our example presentation we add the slide titles to the table of contents, 
make those slide titles links rather than the sections, make the sections bold, 
and the digressions italic

{pstd}
The title of the table of contents can be specified with the {cmd://toctitle} 
command, and you can add text between the title and the table of contentents with 
the {cmd:/*toctxt} and {cmd:toctxt*/} commands

{pstd}
The sourcefile after changing the table contents looks like this:

//ho_ignore {pstd}{stata "doedit example_pres05.do":example_pres05.do}{p_end}
txt*/
//codefile example_pres05.do

//ex
smclpres using example_pres05.do , replace dir(output)
//endex

/*txt
{pstd}
In this case the table of contents also serves as a titlepage. 

{pstd}
You can include a dedicated titlepage using the {cmd://titlepage} and 
{cmd://endtitlepage} commands. 

{pstd}
The sourcefile after adding a title page looks like this:

{pstd}
//ho_ignore {stata "doedit example_pres06.do":example_pres06.do}
txt*/
//codefile example_pres06.do

//ex
smclpres using example_pres06.do , replace dir(output)
//endex
//endslide ---------------------------------------------------------------------

//subsection creating a handout

//slide ------------------------------------------------------------------------
//title Initial handout

/*txt
{pstd}
.smcl presentations are good at illustrating how to use Stata

{pstd}
However, they are inconvenient for the audience if they later want to look 
something up from that presentation

{pstd}
The {cmd:pres2html} command will turn a .smcl presentation into a .html handout

{pstd}{stata "cd output"}{p_end}
{pstd}{stata "pres2html using example_pres06.smcl, replace"}{p_end}
{pstd}{stata "cd .."}{p_end}
txt*/

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Adding graphs to the handout

/*txt
{pstd}
Notice that the graph is not displayed in the handout

{pstd}
You can tell {cmd:pres2html} that a graph needs to be added with the command 
{cmd://graph} {it:graphname}. 

{pstd}
The sourcefile after adding that looks like this:

//ho_ignore {pstd}{stata "doedit example_pres07.do":example_pres07.do}{p_end}
txt*/
//codefile example_pres07.do

/*txt
{pstd}{stata "smclpres using example_pres07.do , replace dir(output)"}{p_end}
{pstd}{stata "cd output"}{p_end}
{pstd}{stata "pres2html using example_pres07.do, replace"}{p_end}
{pstd}{stata "cd .."}{p_end}
txt*/
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Adding contents or output of a .do file to the handout

/*txt
{pstd}
In this presentation I added a lot of links to .do files. In the handout we would
want a copy of those in there. 

{pstd}
This can be done using the {cmd://codefile} {it:filename} command.

{pstd}
In a teaching context I use this when including some small excercises with the
solution in the .do file.
txt*/
//endslide ---------------------------------------------------------------------
